/* DEDLG.C */

#include <demo.g>
#include <demo.rsg>
#include <hwim.h>

GLREF_D PR_DECOMMAN *DatApp2;

#pragma METHOD_CALL

METHOD VOID dedlg_dl_dyn_init(PR_DLGBOX *self)
    {
    INT commid;

    commid=(*(INT *)self->dlgbox.rbuf);
    if (commid==O_DEC_PREVIEW)
        hDlgSetTitleByRid(DELP_PREVIEW_TITLE);
    if (!DatApp2->decomman.dets.dayno)
        return;
    hDlgSetDtedit(1,DatApp2->decomman.dets.dayno);
    hDlgSetNcedit(2,DatApp2->decomman.dets.ndays);
    hDlgSetChlist(3,DatApp2->decomman.dets.gap);
    }

METHOD INT dedlg_dl_key(PR_DLGBOX *self)
    {
    DatApp2->decomman.dets.dayno=hDlgSenseDtedit(1);
    DatApp2->decomman.dets.ndays=hDlgSenseNcedit(2);
    DatApp2->decomman.dets.gap=hDlgSenseChlist(3);
    return(WN_KEY_CHANGED);
    }
